package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````T"5```````!``````````$BQ````
M`````````$``.``.`$``&P`:``8````$````0`````````!``$```````$``
M0```````$`,````````0`P````````@``````````P````0```"4`P``````
M`)0#0```````E`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````$@8````````2!@`````````
M$`````````$````%`````"``````````($`````````@0```````!3X`````
M```%/@`````````0`````````0````0`````8`````````!@0````````&!`
M``````!`2````````$!(`````````!`````````!````!@````"L````````
M`+Q`````````O$```````"@$````````F`0`````````$`````````(````&
M````$*P````````0O$```````!"\0`````````(``````````@````````@`
M````````!`````0```!0`P```````%`#0```````4`-````````@````````
M`"``````````"``````````$````!````'`#````````<`-```````!P`T``
M`````"0`````````)``````````$``````````0````$````(*@````````@
MJ$```````""H0```````(``````````@``````````0`````````4^5T9`0`
M``!0`P```````%`#0```````4`-````````@`````````"``````````"```
M``````!0Y71D!````/"@````````\*!```````#PH$```````/P`````````
M_``````````$`````````%'E=&0&````````````````````````````````
M`````````````````````````!``````````4N5T9`0`````K`````````"\
M0````````+Q`````````!``````````$`````````0`````````$````$```
M``4```!'3E4``H``P`0````!``````````0````4`````P```$=.50!0`EIK
M0HW;E"GYYSH0`/1SQB_,:"]L:6(V-"]L9"UL:6YU>"UX.#8M-C0N<V\N,@`1
M````.0````0````(````(!P0``5`!(8H`@`$@(8!C,*)`"))(`0*F((P0;H`
M`@HY````.@```#T```!`````00```$D```!+````30```%````!1````4@``
M`%,```!5````5@```%@``````````````'OP2FMNQ=\?SMY'+6M_FGPNQ9NV
MU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^J%L8)E/PYMJ
M"4/6A_F<@6:OS&;%N9Q`./*+'$)%U>R)!W#3R=6R<3-BV^T5C"7,##J7"Z?=
MHVM_J9R;X*<""FL:GE`*BA!7H^#[20``````````````````````````````
M`*X````2`````````````````````````&`````2````````````````````
M`````"<!```2`````````````````````````"D"```2````````````````
M`````````/H!```2``````````````````````````$````@````````````
M`````````````&$!```2`````````````````````````'X"```2````````
M`````````````````+H!```2`````````````````````````&P"```2````
M`````````````````````#X!```2`````````````````````````/4````2
M`````````````````````````.4````2`````````````````````````)<!
M```2`````````````````````````+0!```2````````````````````````
M`-<````2`````````````````````````-0!```2````````````````````
M`````"H#```2`````````````````````````$4!```2````````````````
M`````````+,````2`````````````````````````*T!```2````````````
M``````````````D"```2`````````````````````````#<"```2````````
M`````````````````,4!```2`````````````````````````!`````2````
M`````````````````````"T````6`````````````````````````)T````2
M`````````````````````````%$````2`````````````````````````(\!
M```2`````````````````````````(@!```2````````````````````````
M`($````2`````````````````````````-L!```2````````````````````
M`````)X!```2`````````````````````````#`"```2````````````````
M``````````D!```2`````````````````````````%L"```2````````````
M`````````````'@!```2`````````````````````````+@````2````````
M`````````````````%`!```2`````````````````````````%0"```2````
M`````````````````````*8!```2``````````````````````````@"```2
M`````````````````````````#\"```2`````````````````````````&P`
M```2`````````````````````````#(!```2````````````````````````
M`&8!```2`````````````````````````'\!```2````````````````````
M`````.P!```2`````````````````````````$8"```2````````````````
M`````````.0!```2`````````````````````````/X````2````````````
M`````````````!X````2`````````````````````````!`"```2````````
M`````````````````$T"```2`````````````````````````&X!```2````
M`````````````````````+\!```2`````````````````````````!<!```2
M````P"%``````````````````#,#```2``T`,$)```````#,`````````(@#
M```2``T`<#E```````"D!@```````!T"```2``T`P"-````````&`@``````
M`*H"```2``T`("Y````````)`````````,@"```2``T`($!````````&`@``
M`````*X#```2``T`,"Y````````0`@```````&X#```0`!@`0,!`````````
M`````````+L"```2``T`0#!````````F`````````-X"```2``T``#9`````
M``!I`````````#\#```1``\``&!````````$`````````%L#```2``T`P%E`
M``````#)`0```````&8#```2``T`("U````````C`````````(,#```0`!@`
MF,!``````````````````)P#```2``T`H#A```````#-`````````,4#```2
M``T`<#9```````"X`````````$X#```0`!<``,!``````````````````$``
M```2````T"%```````````````````(#```2``T`<#!```````!!`0``````
M`'0"```1`!@`0,!````````(`````````"("```1`!@`8,!````````(````
M`````)4#```0`!<`*,!``````````````````+L#```1`!<`(,!````````(
M`````````,0````2````@"!``````````````````%0#```2``T`T"5`````
M```B`````````'H#```2``T`<%E```````!)`````````%`#```@`!<``,!`
M`````````````````'8"```A`!@`0,!````````(`````````!@#```2``T`
M<#A````````A`````````.P"```2``T`4"U```````#-``````````X#```2
M``T`D%M```````!3`@```````)`````1`!@`<,!````````!`````````,T#
M```2``T`P#%````````_!`````````!?7V=M;VY?<W1A<G1?7P!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E
M<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?
M<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``
M8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K
M`'-T<FQE;@!R;61I<@!R96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I
M9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H
M:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`<W1R
M8VAR`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R
M;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O
M<FL`;&EB<&5R;"YS;RXU+C0P`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`
M7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#
M7S(N-`!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#
M7S(N,BXU``````$``0`!``(``P`!``(`!``"``(``@`!``$``@`"``$``@`"
M``$``@`"``4``@`#``$``0`!``$``@`"``$``@`"``(``0`"``(``0`&``(`
M`@`%``(``0`!``(``@`#``(``@`!``$`!P`(``(``@`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``(``@`!``$``0`!``$``0`"``$`
M`0`!``$``0````$`!P"@`@``$`````````"4D98&```(`-H#```0````M)&6
M!@``!P#E`P``$````!1I:0T```8`\`,``!````"SD98&```%`/H#```0````
M<AEI"0``!``%!```$````'09:0D```,`$00``!````!U&FD)```"`!T$````
M````Z+]````````&````!@``````````````\+]````````2````&@``````
M````````^+]````````&````-0``````````````0,!````````%````3```
M````````````8,!````````%````30``````````````<,!````````%````
M6```````````````*+Y````````'`````0``````````````,+Y````````'
M`````@``````````````.+Y````````'`````P``````````````0+Y`````
M```'````!```````````````2+Y````````'````!0``````````````4+Y`
M```````'````4```````````````6+Y````````'````!P``````````````
M8+Y````````'````"```````````````:+Y````````'````"0``````````
M````<+Y````````'````"@``````````````>+Y````````'````"P``````
M````````@+Y````````'````#```````````````B+Y````````'````#0``
M````````````D+Y````````'````#@``````````````F+Y````````'````
M#P``````````````H+Y````````'````$```````````````J+Y````````'
M````$0``````````````L+Y````````'````$@``````````````N+Y`````
M```'````$P``````````````P+Y````````'````%```````````````R+Y`
M```````'````%0``````````````T+Y````````'````%@``````````````
MV+Y````````'````%P``````````````X+Y````````'````&```````````
M````Z+Y````````'````&0``````````````\+Y````````'````.0``````
M````````^+Y````````'````2@```````````````+]````````'````&P``
M````````````"+]````````'````'```````````````$+]````````'````
M'0``````````````&+]````````'````'@``````````````(+]````````'
M````'P``````````````*+]````````'````(```````````````,+]`````
M```'````(0``````````````.+]````````'````(@``````````````0+]`
M```````'````(P``````````````2+]````````'````)```````````````
M4+]````````'````)0``````````````6+]````````'````)@``````````
M````8+]````````'````)P``````````````:+]````````'````*```````
M````````<+]````````'````*0``````````````>+]````````'````*@``
M````````````@+]````````'````*P``````````````B+]````````'````
M+```````````````D+]````````'````+0``````````````F+]````````'
M````+@``````````````H+]````````'````+P``````````````J+]`````
M```'````,```````````````L+]````````'````,0``````````````N+]`
M```````'````,@``````````````P+]````````'````,P``````````````
MR+]````````'````-```````````````T+]````````'````-@``````````
M````V+]````````'````-P``````````````X+]````````'````.```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%W9\``$B%P'0"_]!(@\0(PP```````````/\U\IT``/\E])T`
M``\?0`#_)?*=``!H`````.G@_____R7JG0``:`$```#IT/____\EXIT``&@"
M````Z<#_____)=J=``!H`P```.FP_____R72G0``:`0```#IH/____\ERIT`
M`&@%````Z9#_____)<*=``!H!@```.F`_____R6ZG0``:`<```#I</____\E
MLIT``&@(````Z6#_____):J=``!H"0```.E0_____R6BG0``:`H```#I0/__
M__\EFIT``&@+````Z3#_____)9*=``!H#````.D@_____R6*G0``:`T```#I
M$/____\E@IT``&@.````Z0#_____)7J=``!H#P```.GP_O___R5RG0``:!``
M``#IX/[___\E:IT``&@1````Z=#^____)6*=``!H$@```.G`_O___R5:G0``
M:!,```#IL/[___\E4IT``&@4````Z:#^____)4J=``!H%0```.F0_O___R5"
MG0``:!8```#I@/[___\E.IT``&@7````Z7#^____)3*=``!H&````.E@_O__
M_R4JG0``:!D```#I4/[___\E(IT``&@:````Z4#^____)1J=``!H&P```.DP
M_O___R42G0``:!P```#I(/[___\E"IT``&@=````Z1#^____)0*=``!H'@``
M`.D`_O___R7ZG```:!\```#I\/W___\E\IP``&@@````Z>#]____)>J<``!H
M(0```.G0_?___R7BG```:"(```#IP/W___\EVIP``&@C````Z;#]____)=*<
M``!H)````.F@_?___R7*G```:"4```#ID/W___\EPIP``&@F````Z8#]____
M);J<``!H)P```.EP_?___R6RG```:"@```#I8/W___\EJIP``&@I````Z5#]
M____):*<``!H*@```.E`_?___R6:G```:"L```#I,/W___\EDIP``&@L````
MZ2#]____)8J<``!H+0```.D0_?___R6"G```:"X```#I`/W___\E>IP``&@O
M````Z?#\____)7*<``!H,````.G@_/___R5JG```:#$```#IT/S___\E8IP`
M`&@R````Z<#\____)5J<``!H,P```.FP_/___R52G```:#0```#IH/S___\E
M2IP``&@U````Z9#\____)4*<``!H-@```.F`_/___R4ZG```:#<```#I</S_
M_P````````````````````#S#Q[Z55-(@^PXB7PD'$B-?"0<2(ET)!!(C70D
M$$B)5"0(9$B+%"4H````2(E4)"A(C50D".AV____NH`@0`"_T"%``$B)UNCD
M.0``@#U=G`````^$&P$``$B+!=";``!D2(L`@(@Z!````XM$)!R->`2-6`-(
M8_](P><#Z+_^__](BWPD$$2+1"0<2(G!2(D%,YP``$B+!TC'00CG84``2,=!
M&.IA0`!(B0%(BP6NFP``2(E!$$&#^`$/CBT!``!(@\<(08/``[H$````9F8N
M#Q^$```````/'X0``````$B+!TAC\H/"`4B#QPA(B03Q1#G"=>I(8])(BSW0
MFP``13'`OM`L0`!(QP31`````(G:Z'G[__^%P`^$A0```$B+/:J;``!(C6PD
M).AP_?__2(GNOZ-@0`")PS'`Z+\!``!(A<!T;TB+/8.;``#H'OO__^B9_/__
M2(M$)"AD2"L$)2@````/A98```!(@\0XB=A;7</H%_S__TB)!5";``!(B<=(
MA<!T;^BC_/__2(L%G)H``&1(BQ#&@K8(````Z;S^__](BSTEFP``Z'#[___I
M:O___TB+/02;``!(A?]T"NBJ'```Z7O___^_6&!``$B)[N@H`0``2(D%X9H`
M`$B)QTB%P`^$6____^O4N@0```#I__[__[\!````Z,_Z___HVOS__V8N#Q^$
M```````Q[4F)T5Y(B>)(@^3P4%1%,<`QR4C'Q\`C0`#_%0>:``#T9BX/'X0`
M``````\?0`##9BX/'X0```````\?1```N"C`0`!(/2C`0`!T$[@`````2(7`
M=`F_*,!``/_@9I##9F8N#Q^$```````/'T``OBC`0`!(@>XHP$``2(GP2,'N
M/TC!^`-(`<9(T?YT$;@`````2(7`=`>_*,!``/_@PV9F+@\?A```````#Q]`
M`/,/'OJ`/>:9````=1-52(GEZ'K____&!=29```!7<.0PV9F+@\?A```````
M#Q]``/,/'OKKBF8N#Q^$``````!!5T%6055!5%532(/L"$R+-6N9``!-A?8/
MA)0````/M@=)B?])B?6$P'0$/#UU444QY$F+'DB%VW0L36/D3(GU3(GB3(G^
M2(G?Z++Y__^%P'4'0H`\(SUT1TB+70A(@\4(2(7;==I(@\0(2(G86UU!7$%=
M05Y!7\,/'X0``````$F)_$$/MD0D`4F#Q`&$P'0$/#UU[D4I_.N89@\?1```
M3"GU2HU<(P%(P?T#08EM`.NT,=OKL&8N#Q^$``````!32('LH````&1(BQPE
M*````$B)G"28````2(G[2(GFZ"S[__^%P'4XBU0D&('B`/```('Z`$```'0(
M@?H`H```=2"^`@```$B)W^AQ^___A<`/E,`/ML#K"0\?@``````QP$B+E"28
M````9$@K%"4H````=0E(@<2@````6\/HG?K__V9F+@\?A```````9I!!54%4
M55-(@>RH````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G[=2M(BX0D
MF````&1(*P0E*`````^%&P$``$B!Q*@```!;74%<05W#9@\?1```Z"/Y__](
MB<5(A<!TR$B)[^@3^___2(7`#X2J````@'@3+DR-8!-U$$&`?"0!`'3=#Q^$
M``````"`>!,N#X2>````2(G?Z+[X__],B>=)B<7HL_C__T&-?`4"2&/_Z`;X
M__]-B>%)B=BY!&!``$F)Q4B)Q[X!````,<!(Q\+_____Z$+Z__],B>](B>;H
MA_C__TR)[X/X_W00BT0D&"4`\```/0!```!T5^CJ]___3(GOZ$+X__](B>_H
M:OK__TB%P`^%5____Y!(B>_HZ/G__TB)W^C0]___Z?C^__\/'P!!@'PD`2X/
MA5;___]!@'PD`@`/A!7____I1?___P\?`.BC_O__ZZ?H+/G__V9F+@\?A```
M````D$%7,<!!5D%505154TB)^TB#[!B`/CUD2(LL)2@```!(B6PD"$B)]0^4
MP$@!Q4B)[^B[]___2(UT)`1(B=])B<0QP.CY_/__2(7`#X0H`0``2(G'28G%
MZ)7W__],.>`/@_0```!,8W0D!$G!Y@,/M@.$P`^$T`$``#P]#X3(`0``2(G8
M9F8N#Q^$``````!F9BX/'X0```````\?@``````/ME`!2(/``832=`6`^CUU
M[T@IV$B83(LM`Y8``$J-?"`"Z(GV__]-`?5)B44`2(7`=%Y(BP7FE0``2(U+
M`4J+%#`/M@.(`CP]="J$P'45ZR1F9BX/'X0```````\?0``\/701#[8!2(/"
M`4B#P0&(`H3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)`AD
M2"L$)2@````/A1<!``!(@\086UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%
M`$&(5`4`2(/``832=>[KO0\?0`!,BSU!E0``28,_``^$Q@```$R)^$4Q[69F
M+@\?A```````9@\?1```2(/`"$2)ZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP4W
ME0``A<!U6\<%*94```$```!(B??H>?7__TB%P`^$4?___TUC]4R)_DB)QTG!
MY@-,B?+HR_;__TB)!<24``!(B<%!C44!1(EL)`1(F$C'!,$`````Z5;^__]F
M#Q^$``````!,B?_HJ/?__TB)!9&4``!(B<%(A<`/A/;^__]-8_5)P>8#Z[L/
M'T``,<#I9_[__[X0````13'MZ5_____HO_;__V9F+@\?A```````#Q]``$%5
M05154TB![``0``!(@PPD`$B#[!BZ_P\``&1(BRPE*````$B)K"0($```2(GU
M2(G[2(GFOPI@0`#H`?;__X7`?A6)P8/H`4F)Y$ACT(`\%`!U3(7`=3=(BP6A
MDP``2(GJ2(G>9$B+..C"]/__2(N$)`@0``!D2"L$)2@```!U4DB!Q!@0``!;
M74%<05W#B<%F9BX/'X0```````\?0`!,8^F^+P```$R)YTR)ZNB]\___2(7`
M=*!(BP5!DP``3(GI3(GB2(G>9$B+..A?]?__ZYOHV/7__P\?A```````\P\>
M^E.Y<*!``+K`(4``OAE@0`!(BQT%DP``9$B+.^AL]O__9$B+.T4QR5M!N,1A
M0`"Z($!``+XU8$``3(G!Z<ST__]F9BX/'X0``````)#S#Q[ZN7"@0`"ZP"%`
M`+X98$``2(L%MI(``&1(BSCI'?;__V9F+@\?A```````9I#S#Q[Z55-(@>P`
M$```2(,,)`!(@>P`$```2(,,)`!(@^PH9$B+!"4H````2(F$)!@@```QP$B-
MK"00$```Z)[S__^Y2F!``$&Y%6!``$B)YT&)P+H!$```O@$````QP.A\]?__
MN@`0``!(B>Y(B>?H;/3__S')A<!X+HUX`4B)PTAC_^CX\O__2(G!2(7`=!A(
M8]M(B>Y(B<=(B=KHC_7__\8$&`!(B<%(BX0D&"```&1(*P0E*````'4-2('$
M*"```$B)R%M=P^B#]/__#Q\`\P\>^NDG____#Q^``````/,/'OI!5D%50515
M4TB![``0``!(@PPD`$B![+````!D2(L$)2@```!(B80DJ!```#'`28G\2(GS
MOUA@0`!(C70D#.A)^/__OB\```!,B>=(B<7HR?/__TB%P'0\,<!,B>:_86!`
M`.CE^O__3(G@2(N4)*@0``!D2"L4)2@````/A88!``!(@<2P$```6UU!7$%=
M05[##Q\`2(G?3(VL)*````#HJ//__[YN8$``2(G'Z-OS__](B<-(A<!TGX`[
M``^$ZP```&8N#Q^$``````!(A>UT$TB)WDB)[^B@\___A<`/A*@```!(B=_H
M4/+__TB-5`/_28G&2#G3<A_K+69F+@\?A```````9@\?1```Q@(`2(/J`4@Y
MTW0%@#HO=.](B=_H%_+__TF)QDR)Y^@,\O__28U$!@%(/?\/```/AQ?___](
M@^P(N71A0`"Z`!```#'`051!N7!@0`!)B=B^`0```$R)[^B3\___2(UT)"!,
MB>_HUO'__UI9A<!U$(M$)"@E`/```#T`@```=%"^;F!``#'_Z/3R__](B<-(
MA<`/A+3^__^`.P`/A1____](A>UT!H!]`"YT%$&^`0```+M68$``Z6#___\/
M'T``@'T!`'2ZZ^0/'X0``````+X!````3(GOZ"/S__^%P'6?3(GNOV%@0`#H
M4OG__TR)[^A*\O__Z6/^___H8/+___,/'OI3OB\```!(B?OHKO'__TB-4`%(
MA<!(#T7:2(G?6^D:\O__9BX/'X0``````/,/'OI54TB![``0``!(@PPD`$B#
M[!AD2(L$)2@```!(B80D"!```#'`2(7_#X3.````@#\`2(G[#X3"````Z+WP
M__](C5`!2('Z`!````^'Y````$B)Y4B)YX/Z"'(.B=%(B=[!Z0/S2*5(B?,Q
MR?;"!'0)BPN)#[D$````]L("=`Y$#[<$"V9$B00/2(/!`H/B`70'#[84"X@4
M#TB-1`7_2#G%<A;K&0\?A```````Q@``2(/H`4@YZ'0%@#@O=.^^+P```$B)
M[^C"\/__2(7`="U(.<5R6$B)[^@P\?__2(N4)`@0``!D2"L4)2@```!U24B!
MQ!@0``!;7<,/'P!(BX0D"!```&1(*P0E*````'4I2('$&!```+]68$``6UWI
MZO#__V8N#Q^$``````#&``#KHP\?`#'`ZZ3H[_#__V9F+@\?A```````#Q]`
M`/,/'OI32(/L$&1(BQPE*````$B)7"0(2(U<)`0/'T``,<!(B=Z_<F!``.C1
M]/__2(7`=#1(8U0D!$B+!4".``!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```,<!(B=Z_>V!``.B)]/__2(7`=#Q(8U0D!$B+!?B-
M``!(C0302(M0"$B)$$B%TG30#Q^$``````!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$```QP$B)WK^#8$``Z#GT__](A<!T/$AC5"0$2(L%J(T``$B-!-!(BU`(
M2(D02(72=-`/'X0``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(G>
MOXQ@0`#HZ?/__TB%P'0\2&-4)`1(BP58C0``2(T$T$B+4`A(B1!(A=)TT`\?
MA```````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(B=Z_DV!``.B9\___
M2(7`=#Q(8U0D!$B+!0B-``!(C0302(M0"$B)$$B%TG30#Q^$``````!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B)WK^C8$``Z$GS__](A<!T/$AC5"0$
M2(L%N(P``$B-!-!(BU`(2(D02(72=-`/'X0``````$B+4!!(@\`(2(D02(72
M=?#KMF8/'T0``#'`2(G>OUA@0`#H^?+__TB%P'0\2&-4)`1(BP5HC```2(T$
MT$B+4`A(B1!(A=)TT`\?A```````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M,<!(B=Z_KV!``.BI\O__2(7`=#Q(8U0D!$B+!1B,``!(C0302(M0"$B)$$B%
MTG30#Q^$``````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$```QP$B)WK^Y8$``
MZ%GR__](A<!T/$AC5"0$2(L%R(L``$B-!-!(BU`(2(D02(72=-`/'X0`````
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(G>O\-@0`#H"?+__TB%P'0\
M2&-4)`1(BP5XBP``2(T$T$B+4`A(B1!(A=)TT`\?A```````2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```,<!(B=Z_86!``.BY\?__2(7`=#Q(8U0D!$B+!2B+
M``!(C0302(M0"$B)$$B%TG30#Q^$``````!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$``!(B=Z_S6!``.AK\?__2(7`=`](B<:_N6!``#'`Z!?T__\QP$B)WK_>
M8$``Z$CQ__](A<!T#TB)QK_P8$``,<#H]//__TB)WK_[8$``,<#H)?'__TB)
MQDB%P'0ROUA@0``QP.C1\___2(M$)`AD2"L$)2@```!U.TB#Q!"^'&%``+^3
M8$``,<!;Z:OS__\QP$B)WK\+84``Z-SP__](A<!TQDB)QK^O8$``,<#HB//_
M_^NUZ*'L__^0\P\>^DB#[!B_KV!``&1(BP0E*````$B)1"0(,<!(C70D!.B9
M\/__2(7`=#0/MA"`^C`/E,"$T@^4P@G0@_`!#[;`2(M4)`AD2"L4)2@```!U
M$DB#Q!C#9@\?A```````,<#KWN@W[/__#Q^``````/,/'OI06$B![-@```!(
MB70D*$B)5"0P2(E,)#A,B40D0$R)3"1(A,!T-P\I1"10#RE,)&`/*50D<`\I
MG"2`````#RFD))`````/*:PDH`````\IM"2P````#RF\),````!D2(L$)2@`
M``!(B40D&#'`2(GZ2(V$).````!(B>%(BSUJB0``2(E$)`B^`0```$B-1"0@
MQP0D"````,=$)`0P````2(E$)!#H@NK__[__````Z&CI__\/'X0``````$%4
M55-,C9PD``#__TB![``0``!(@PPD`$PYW'7O2(/L$+H"````,?9D3(LD)2@`
M``!,B:0D"``!`$&)_$B)X^B<Z___2(UH_TB)ZDC!^C](P>HP2(U$%0`/M\!(
M*=!(*<4/B*4```!F#Q^$```````QTDB)[D2)Y^ACZ___2(/X_P^$F@```+H(
M``$`2(G>1(GGZ.GH__^#^/]T>4B82(/X!W942(U$`_A(.=AR2DB+%2N(``#K
M$F8/'X0``````$B#Z`%(.=AR+T@[$'7R2"G82`'H2(N4)`@``0!D2"L4)2@`
M``!U1DB!Q!```0!;74%<PP\?1```2('M```!`$B!_0``__\/A63___](Q\#_
M____Z[^_*V%``#'`Z!_^__^_'F%``#'`Z!/^___H/NK__V9F+@\?A```````
M#Q\`\P\>^DB#[`CH8^K__XG'Z+SH__](A<!T`TB+`$B#Q`C#9F8N#Q^$````
M```/'T``\P\>^D%454B)_;\W84``4TB#[!!D2(L$)2@```!(B40D"#'`2(UT
M)`3H\NW__TB%P'0(@#@`2(G#=2U(BT0D"&1(*P0E*````'5]2(GN2(/$$+\W
M84``,<!;74%<Z7[P__]F#Q]$``!(B>_H8.C__TB)WTF)Q.A5Z/__28U\!`+H
MJ^?__TB#[`A)B>BY=&%``%-(Q\+_____2(G'28G$0;EN8$``O@$````QP.C?
MZ?__6%I(BT0D"&1(*P0E*````'4%3(GFZX;H,^G__P\?`/,/'OI!5T%6055!
M5$F)_+]88$``55-(@>QX`0``\P]^!>MF``!D2(L$)2@```!(B80D:`$``#'`
M2(UL)!Q(QT0D,``````/%@7+9@``2(GN2,>$)(@`````````#RE$)"#S#WX%
MMV8``$C'1"10``````\6!:]F```/$40D:/,/?@6J9@``#Q8%JV8```\11"1X
M\P]^!:9F```/%@6G9@``#RE$)$#HI>S__TB%P'0,@#@`2(G##X5T!```Z*_H
M__^)Q^@(Y___2(7`#X2_`P``2(L82(7;#X2S`P``2(G?Z!OG__](C7P``>AQ
MYO__1`^V`TF)QDF)Q46$P'0R9I!%#[;`3(GWN6UA0``QP$C'PO____^^`0``
M`$B#PP%)@\8"Z)GH__]$#[8#183`==!,C70D:+_P8$``ZQ`/'T``28L^28/&
M"$B%_W0T2(GN,<#H^NO__TB)PTB%P'3B@#@`=-U(B<?HI>S__X7`=-%(B=_H
MF>?__TB)PTB%P'4TD$R-="0@28L>2(7;=":`.P`/A.H"``!(B=_H<NS__X7`
M#X7Z````28M>"$F#Q@A(A=MUVDB)W^A%YO__3(GO28G&Z#KF__]%C;P&!`0`
M`$UC_TR)_^B'Y?__055)B=A!N7!@0`!H>V%``$B)QTF)QKER84``2,?"____
M_[X!````,<#HN>?__TR)][[``0``Z!SH__]?05B#^/]U$NC?YO__1(L(08/Y
M$0^%V`(``$B-M"20````3(GWZ"+G__^)PX7`='Q)BPPD2(L]H80``$V)\#'`
MNC!B0`"^`0```.B=Y/__13'M9BX/'X0``````$B+A"1H`0``9$@K!"4H````
M#X4,!```2('$>`$``$R)Z%M=05Q!74%>05_##Q]``$B)WTF#Q@CH9.;__TB)
MPTB%P`^$S?[__^GV_O__#Q\`BX0DJ````"4`\```/0!````/A6W___]$BZPD
MK````.B,YO__03G%#X57____BX0DJ````"7_`0``/<`!```/A4#___],B?_H
M5.3__TB)[K]"84``28G%,<#H,NK__TB%P`^$20(``$F+/"1(B<;HC?'__TF)
MQTB%P`^$,0(``$R)_^BYY/__2(G"@_@#?D%(F+Z`84``2(E4)`A)C7P'_.C;
MY?__A<!U)TB+5"0(@_H$#X3B`@``C4+[2)A!@#P'+P^$T@(``&8/'X0`````
M`#'`2(GNOZ]@0`#HL>G__TB%P`^$V`$```^V`(3`#X3-`0``/#`/A,4!``"^
M'&%``+^O8$``,<#H1.S__^COX___:,1A0`!-B?!,B>]02,?"_____T&Y<&!`
M`#'`N:1A0`"^`0```.C%Y?__6%KK1I#H^^3__X,X$75-Z+'C__^#PP%(@^P(
M38GP:,1A0`!!N7!@0`!,B>^YLF%``%-(Q\+_____O@$```!0,<#H?^7__TB#
MQ""^P`$``$R)[^C>Y?__@_C_=*E,B??HD>/__TR)[K]88$``,<#HHNO__TR)
M[^BZ^O__Z?7]__\/'T0``#';Z2S]__]F#Q^$``````!,C6PD0&9F+@\?A```
M````28M]`$B%_W0D2(GN,<#HG>C__TB)QTB%P'0%@#@`=3!)BWT(28/%"$B%
M_W7<OPT```"[1V%``.B$XO__0;A3````28G&28G%Z1/\__\/'P#H&^3__TF#
MQ0A(B<-(A<!TG^G7^___28L,)$B+/=^!``!-B?`QP+KP84``O@$```#HV^'_
M_^DY_?__9@\?1```2(G'Z/CY__](BX0D:`$``&1(*P0E*`````^%1`$``$B!
MQ'@!``!(B=];74%<05U!7D%?Z:CC__\/'X0``````$V+/"3IQOW__P\?@```
M```Q]DR)_S'`Z!3C__^)Q87`#X0E_O__B<?H(_C__TF)Q$B%P`^($O[__S'2
M2(UP]HGOZ.KC__](C;0D*@$``+H&````B>_H=N'__TB#^`8/A<0```"!O"0J
M`0```$-!0P^%UOW__V:!O"0N`0``2$4/A<;]__\QTDF-="3.B>_HG>/__TB-
MG"0P`0``NB@```")[TB)WN@FX?__2(/X*'5XQH0D6`$```!-B?!,B>\QP&C$
M84``N95A0`"^`0```$&Y<&!``%-(Q\+_____Z&[C__]97NG^_?__38MD)`A-
MA>0/A"G]__],B>?HD>'__TB#^`,/AA?]__])C7P$_+Z%84``Z+CB__^%P$T/
M1/SI_?S__^B8XO__OXIA0``QP.A<]O__9F8N#Q^$``````"0\P\>^D%4OY-@
M0`!54TB#[!!D2(L<)2@```!(B5PD"$B+':I_``!,C60D!$R)YF1(BRL/MH6P
M````B(6Q````,<#H6N;__TB%P'0)@#@Q#X1<`0``,<#H1?'__V1(BRM(B>^Y
M`P```+H!````OL-A0`#H6N#__TB)Q4B%P'0F2(M`$&1(BSNZQ6%``$B+,.AM
MX/__2(M%$$B+,/9&#D`/A30!``!D2(L[N0,```"Z`0```+[*84``Z!3@__](
MB<5(A<!T+K]A8$``3(GF,<#HS>7__TB)PDB+11!(BSA(A=(/A-H```!(B?YD
M2(L[Z`[@__]D2(L[N@$```"^S&%``.@;W___9$B+.[KA84``2(G&Z.K?__]D
M2(L#3(GFOUA@0`#&@+$`````,<#H<.7__TB)!2E_``!(B<-(A<!T0;[``0``
M2(G?Z#3B__^-4`&#^@%V"8/X$0^%B0```$B+1"0(9$@K!"4H````#X60````
M2(/$$%M=05S#9@\?1```2(L]X7X``.C$]___2(D%S7X``$B)PTB%P'6DOXAB
M0``QP.@IX?__9@\?A```````@'@!``^$I?[__^F5_O__D$B+%:%^``!(BS+H
M`>K__^D>____#Q]``&1(BSOHC^#__^F^_O__B<%(BP5Y?@``2(G:O[!B0`!(
MBS`QP.C/X/__Z'K@__]F+@\?A```````\P\>^E532(G[OZ]@0`!(@^P89$B+
M!"4H````2(E$)`@QP$B-="0$Z&3D__](A<!T'`^V$(32#Y3`@/HP#Y3""-!U
M"DB%VW0%@#L`=1M(BT0D"&1(*P0E*````'5J2(/$&%M=PP\?0`!(B=_HT.W_
M_[XO````2(G'2(G%Z%#?__](C5`!2(7`2`]%ZDB)[^B]W___N@0```"^>V%`
M`$B)Q^CKW?__A<!UI$B+1"0(9$@K!"4H````=0Y(@\082(G?6UWI&>7__^BD
MW___#Q]``$%7059!54%455-(@>R8`@``9$B+-"4H````2(FT)(@"``!(B?Y)
MB>!,C90D@````$B)YTR-3CAF#Q^$``````!!BP%)BPE(@\<028/!"`_(B<!(
MB<I(B4?P2(G(2,'J($C!Z"A(P>DX)0#_``!("<A(B=%(P>((2,'A&('B``#_
M`(G)2`G(2`G02(E'^$PYUW6NN_____]F#V]$)!!(C40D:&8/;UPD(&9(#V[K
M9@]O5"0P28V0:`(``&8/;.UFD/,/;PAF#V_B9@]O4-A(@\`09@_O0(AF#^_*
M9@_OP68/;\AF#W/P`68/<]$?9@_KP68/V\4/*4`(9@]OPV8/;]Q(.=!UNTR+
M#DR+7A!(BWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,
M"YEY@EJ-E#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I(
M"<),B=A)P>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)
MR$R)R4C!Z0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-
MB>))P>(%30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G5
M2#'0B==,(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!
MX!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%
M3`GI3(ML)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!
MB=),(<!,,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0L
MF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!
M`=1(B<I(P>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`
M3`'038GB2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)
M^$V)U4@QPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG!
M[`)(P>(>18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!
M2,'A!4P)Z4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))
MP>T;08G"3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_
M3XVD+)EY@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+
M;"1@00'$2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A
M^DPQPDP!TDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY
M@EI("?I-B=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,
MB>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!
MRDR)P4C!X05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-
M2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H
M`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!
MY`5-">Q&C2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'0
M2<'L&XG12"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC!
M[P)%B=)/C80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-
M">!%B<!,`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY
M@EI-B>5(,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,
M"=%-B<)%B<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!
MX@5,"=*)TD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P
M````23'41#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M
M`DC!X!Y%B>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(
MP>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-
MI!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"
M28G(2`.$),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;
M2,'@!4P)P(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''
M1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$
MB>=,"=%)B<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B
M!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@
M3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!(
M"?A(B=>)TD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)
M^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD
M$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))
MB<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`
M20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'K
MV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)
MP$@#A"0(`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'5
M3(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H
M&TC!X`5,"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#
ME"08`0``2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G1
M2<'J`DC!X1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)
MB?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4Q
MZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH
M2`.,)"@!``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)
MP>P;2,'G!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!
M``!%,>I)B?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%
MB=),"<)-B>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%
M3`G`1(T$`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1`
M`0``2`'"3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)
MY$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE
M2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPA
MPDP)\DR+M"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG!
M[`)(P>(>B?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)
M_DP!T4F)^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)
M"<Y)(?Y,(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP
M00'02(GZ2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``
M20'&30'T38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)
MY$P)T4&)RDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N
M&TG!Y05-"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)
M\4R+M"1X`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G!
M[`)(P>$>B?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!
MTDF)^DG![AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5(
M(?E-(>9,"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G6
M00'(2(GY2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&
M30'T38G&3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)
MT4F)UD&)TDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!
MY05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+
MM"2@`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>
MB?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)
M^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,
M(>I,"?),B[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ
M2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T
M38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)
MSD&)RDTAQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-
M"?5!`=5,B<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(
M`0``20'`3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!
MYQY,">=!B?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``
M2`'*3(G!2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-
M08G.3"''32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)
MP$@!QTR)P$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B
M38GL2`'*3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$
MB=%%B<!-,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT
M38GN2<'M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q
M\DV)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)
MT4V)ZDDQTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)
MR4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4Q
MZ$V)U4D!R$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)
M\4R+M"0(`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)
MTD@!UTR)TDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4Q
MX$V)]$D!T$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)
MZDR+K"08`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)
MR4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4Q
MT$V)ZDD!R$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)
MX4R+I"0H`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)
MTD@!UTR)ZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q
M\$V)YDD!T$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+
ME"0X`@``20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)
MR4@!STR)X4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4Q
MZ$V)U4D!R$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+
MM"1(`@``20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)
MTD@!UTR)TDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!
MQT0QPDV)\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)
MZDR+K"18`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)
MR4@!STR)\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4Q
MXDV)[$P!T4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,
MBZ0D:`(``$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G2
M2<'L&TC!X@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%
MB<!$,?%)B=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>
MB<E-">)-,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!
M^$R)5AA(B09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$
M)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^@VR?__9@\?1```\P\>^DB#[`B_
M@````.A.Q___9@]O!39'``!(QT`P``````\1`&8/;P4S1P``QT!X``````\1
M0!!F#V\%,$<```\10"!(@\0(PP\?@`````#S#Q[Z05=(8\))B?]!5DR-=SA!
M54F)]4%428G$55-(@^P82(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(
MB4<P2&-'>(7`#X4A`0``08/\/WY^1(GE3(GKP>T&C47_2,'E!HE$)`1,`>U(
MB40D"&9F+@\?A```````#Q]``/,/;P-,B?](@\-`00\1!O,/;T/000\11A#S
M#V]#X$$/$48@\P]O0_!!#Q%&,.B.Z/__2#GK=<F+1"0$]]C!X`9%C60$P$B+
M1"0(2,'@!DV-;`5`26/$2(/X"')L28M5`$F-=T!,B?%(@^;X28E7.$F+5`7X
M2"GQ22G-28E4!OA(`<A(@^#X2(/X"'(D2(/@^#'228M,%0!(B0P62(/""$@Y
MPG+N9F8N#Q^$``````"018EG>$B#Q!A;74%<05U!7D%?PP\?1```J`1U9DB%
MP'3?00^V50!!B%<XJ`)TTD$/MU0%_F9!B50&_NO$#Q]``+U`````28T\!DR)
M[BG%1#GE00]/[$ACW4B)VN@PR/__08M'>`'H08E'>(/X0'653(G_02GL20'=
MZ)/G___IG?[__T&+50!!B5<X08M4!?Q!B50&_.EG____#Q^``````/,/'OI!
M5DR-=CA!54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#X#^-2`'&1`8X@$AC
MP4P!\(/Y.`^.@0$``+I`````*<IT#S')B<Z#P0'&!#``.=%R\TB)W^@1Y___
M9@_OP`\10SA)QT8P`````$$/$48000\11B!,B>)!#[;%38GH3(GO2,'J&$C!
MX`A,B>%)P>@028G13(GJ2,'O&`^V]DR)XDC!Z1!("?!!#[;P#[;)2,'@"$@)
M\$`/MO=(B=](P>`(2`GP00^V]$C!X`A("?`/MO9!#[;12,'@"$@)\$C!X`A(
M"<A(P>`(2`G02(E#<.AXYO__2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(BP.(
M90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#"(AE!DB+0PB(10=(
MBT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(10M(BT,82,'H&(A%
M#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0
MB$412(M#((AE$DB+0R"(11-;74%<05U!7ND8Q/__#Q^$``````"Z.````#'V
M*<J#^@AS*O;"!'5MA=(/A)[^___&``#VP@(/A)+^__\QR6:)3!#^Z8;^__\/
M'T0``(G12,<``````$C'1`CX`````$B-2`A(@^'X2"G(`<*#XOB#^@@/@E;^
M__^#XO@QP(G'@\`(2(DT.3G0<O/I/_[__V8/'T0``,<``````,=$$/P`````
MZ2;^__]F+@\?A```````#Q\`2(L-$6(``.FDPO__2(/L"$B#Q`C#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M````3F%```````!68$```````.E@0```````4V%````````&84```````%MA
M0```````7V%```````!D84````````$C16<`````B:O-[P````#^W+J8````
M`'94,A``````\.'2PP````````````````$;`SO\````'@```#!___]8`0``
MT(+___0%``#@A/__&`$``!"%__]$`0``T(7__X`!``"0AO__S`$``""'___P
M`0``D(C__RP"````B___>`(``."+__^X`@``,(S__]0"``!@C/__Z`(``#"-
M__\<`P``0(W__S`#``!0C___C`,``("/__^H`P``T)#__^0#```0E?__"`0`
M`("5__\D!```0);__T`$``"`E___@`0``+"7__^8!```@)C__]@$```PG___
MB`4``$"A__^\!0``$*+__R`&``"`N/__<`8``-"X__^(!@``H+K__]0&````
MO?__&`<````````4``````````%Z4@`!>!`!&PP'")`!!Q`0````'````,"#
M__\B`````````!0``````````7I2``%X$`$;#`<(D`$``!`````<````Q(/_
M_P$`````````)````#````#0??__D`,````.$$8.&$H/"W<(@``_&CLJ,R0B
M`````$@```!8````2(3__[8`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D$..(,'1`Y``EP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`@````I````+R$
M__^#`````$$.$(,"1PZP`0)T"@X000X(00LX````R````"B%__]D`0```$(.
M$(T"0@X8C`-!#B"&!$$.*(,%1P[0`7X*#BA!#B!!#AA"#A!"#@A'"P!(````
M!`$``%R&__]A`@```$(.$(\"1`X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.
M4`,V`0H..$$.,$$.*$(.($(.&$(.$$(."$4+/````%`!``"`B/__V`````!"
M#A"-`D(.&(P#00X@A@1!#BB#!4<.J"!)#L`@`G(*#BA!#B!!#AA"#A!"#@A!
M"Q@```"0`0``((G__T0`````10X0@P)G#@@````0````K`$``%2)__\C````
M`````#````#``0``<(G__\T`````10X0A@)!#AB#`T<.F"!,#IA`20[`0`*@
M"@X81`X000X(00L0````]`$```R*__\)`````````%@````(`@``"(K__Q`"
M````1@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.L"!,#N`A`FT*#C!!#BA!
M#B!"#AA"#A!"#@A$"P*Q#N@A3@[P(60.Z"%!#N`A````&````&0"``"\B___
M)@````!%#A"#`EP."````#@```"``@``T(O__T$!````10X0A@)!#AB#`T<.
MF"!)#K`@`N0*#AA!#A!!#@A$"UH*#AA&#A!!#@A/"R````"\`@``Y(S__S\$
M````10X0@P)$#B`#^@,*#A!-#@A%"Q@```#@`@```)'__VD`````2`X@`DX*
M#@A*"P`8````_`(``%21__^X`````$4.$$$."$<.X`$`/````!@#``#XD?__
M,@$```!"#A",`D$.&(8#00X@@P1(#`N@@`11#0=$#K"`!`+-"@X@00X800X0
M0@X(1@L``!0```!8`P``^)+__R$`````2`X06`X(`#P```!P`P``$)/__\T`
M````1@X0C`)!#AB&`TD.((,$1`XP?@H.($@.&$$.$$(."$L+80XX20Y`8`XX
M00XP``"L````L`,``*"3__^D!@```$8.$(\"0@X8C@-"#B"-!$(.*(P%20XP
MA@9!#CB#!T<.L`,#O@$.N`-.#L`#;`ZX`T(.L`,"=PH..$0.,$$.*$(.($(.
M&$(.$$(."$4+`S8!#K@#1P[``U\.N`-!#K`#60ZX`T@.P`-/#L@#30[0`TL.
ML`,#$0$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P+%#K@#40[``TT.N`-!#K`#
M`#````!@!```H)G__P8"````1@X0C`)&#AB&`T$.((,$1`XP`V0!"@X@00X8
M00X00@X(1PLT````E`0``'R;___,`````$4.$(8"00X8@P-,#C`"3PH.&$$.
M$$$."$4+`E4*#AA$#A!!#@A%"R@```#,!```U'S__P8"````10X0A@)!#AB#
M`T0.4`-E`0H.&$,.$$$."$$+3````/@$``#HF___:A8```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`TD6"@XX00XP00XH0@X@0@X80@X0
M0@X(00L````4````2`4```BR__])`````$@.$`)`#@A(````8`4``$"R___)
M`0```$8.$(\"2`X8C@-&#B"-!$4.*(P%1`XPA@9!#CB#!T0.4`,6`0H..$$.
M,$$.*$(.($(.&$(.$$(."$8+0````*P%``#$L___4P(```!&#A".`D8.&(T#
M0@X@C`1!#BB&!40.,(,&`YD!"@XH00X@0@X80@X00@X(30L````````0````
M\`4``."U__\,```````````````$````$`````$```!'3E4```````,````"
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````+`F0```````@"9````````!````````
M`)`"`````````0````````"@`@````````P``````````"!````````-````
M`````/Q=0```````&0``````````O$```````!L`````````"``````````:
M``````````B\0```````'``````````(`````````/7^_V\`````L`-`````
M```%`````````!@-0```````!@````````"H!$````````H`````````*00`
M```````+`````````!@`````````%0````````````````````,`````````
M$+Y````````"`````````$`%````````%``````````'`````````!<`````
M````"!-````````'`````````'@20```````"`````````"0``````````D`
M````````&``````````>``````````@`````````^___;P`````!````````
M`/[__V\`````^!%```````#___]O``````$`````````\/__;P````!"$4``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````!"\0````````````````````````````#8@0```````1B!`
M``````!6($```````&8@0```````=B!```````"&($```````)8@0```````
MIB!```````"V($```````,8@0```````UB!```````#F($```````/8@0```
M````!B%````````6(4```````"8A0```````-B%```````!&(4```````%8A
M0```````9B%```````!V(4```````(8A0```````EB%```````"F(4``````
M`+8A0```````QB%```````#6(4```````.8A0```````]B%````````&(D``
M`````!8B0```````)B)````````V(D```````$8B0```````5B)```````!F
M(D```````'8B0```````AB)```````"6(D```````*8B0```````MB)`````
M``#&(D```````-8B0```````YB)```````#V(D````````8C0```````%B-`
M```````F(T```````#8C0```````1B-```````!6(T```````&8C0```````
M=B-```````"&(T```````)8C0```````IB-`````````````````````````
M````````````````````````````````````"E!!4BYP;0H``````````/AB
M0```````1T-#.B`H07)G;W,@,30N,BXP+3$T*2`Q-"XR+C```"YS:'-T<G1A
M8@`N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E
M<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YN;W1E+D%"
M22UT86<`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```'`````@````````!0`T```````%`#````````(```````````````````
M``@````````````````````>````!P````(`````````<`-```````!P`P``
M`````"0````````````````````$````````````````````,0````$````"
M`````````)0#0```````E`,````````<`````````````````````0``````
M`````````````#D```#V__]O`@````````"P`T```````+`#````````^```
M```````%``````````@```````````````````!#````"P````(`````````
MJ`1```````"H!````````'`(````````!@````$````(`````````!@`````
M````2P````,````"`````````!@-0```````&`T````````I!```````````
M`````````0```````````````````%,```#___]O`@````````!"$4``````
M`$(1````````M``````````%``````````(``````````@````````!@````
M_O__;P(`````````^!%```````#X$0```````(``````````!@````$````(
M````````````````````;P````0````"`````````'@20```````>!(`````
M``"0``````````4`````````"``````````8`````````'D````$````0@``
M```````($T````````@3````````0`4````````%````%@````@`````````
M&`````````"#`````0````8``````````"!`````````(````````!<`````
M```````````````$````````````````````?@````$````&`````````"`@
M0```````("````````"0`P``````````````````$``````````0````````
M`(D````!````!@````````#`(T```````,`C````````/#H`````````````
M`````"````````````````````"/`````0````8`````````_%U```````#\
M70````````D````````````````````$````````````````````E0````$`
M```"``````````!@0````````&````````#P0```````````````````$```
M`````````````````)T````!`````@````````#PH$```````/"@````````
M_`````````````````````0```````````````````"K`````0````(`````
M````\*%```````#PH0```````#`&```````````````````(````````````
M````````M0````<````"`````````""H0```````(*@````````@````````
M````````````!````````````````````,,````.`````P``````````O$``
M``````"L````````"`````````````````````@`````````"`````````#/
M````#P````,`````````"+Q````````(K`````````@`````````````````
M```(``````````@`````````VP````8````#`````````!"\0```````$*P`
M`````````@````````8`````````"``````````0`````````.0````!````
M`P`````````0OD```````!"N````````\`$```````````````````@`````
M````"`````````#I`````0````,``````````,!`````````L````````"@`
M```````````````````(````````````````````[P````@````#````````
M`$#`0```````*+````````!8````````````````````(```````````````
M`````/0````!````,````````````````````"BP````````'@``````````
M``````````$``````````0`````````!`````P``````````````````````
J``!&L````````/T````````````````````!````````````````````
